==> haskell-persistent-template-2.5.4-47-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.4
id: persistent-template-2.5.4-BDPADbUXVyNCfwmAzyLuXa
key: persistent-template-2.5.4-BDPADbUXVyNCfwmAzyLuXa
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
abi: 1eb097134c71ee50f4c6a592d79c5061
exposed: True
exposed-modules:
    Database.Persist.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-template-2.5.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-template-2.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/persistent-template-2.5.4
hs-libraries: HSpersistent-template-2.5.4-BDPADbUXVyNCfwmAzyLuXa
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
    persistent-2.8.2-BbTUdKeuqUZ8e0qemiYNmw
    monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq bytestring-0.10.8.2
    text-1.2.3.0 transformers-0.5.5.0 containers-0.5.11.0
    aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO
    aeson-compat-0.3.8-LBSxmI0HRL2BJfrud1ev5q
    monad-logger-0.3.28.5-69Y7FXssjPV28LuWkhfKtw
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
    http-api-data-0.3.8.1-DbbYF9lweepAWqzK9OsOgh ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             persistent-2.8.2-BbTUdKeuqUZ8e0qemiYNmw=4bb3e8e7df5b05894c2cb0ca1d056982
             monad-control-1.0.2.3-DxusezgvvO4D8Mw0qz5Ueq=87bdbc4e9457b26289613d38f0adffd2
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             aeson-1.3.1.1-ArWpZy1DbZ6Lxt3YgJqPBO=63ce14baf2a7c28abbc692d9e7dd92cc
             aeson-compat-0.3.8-LBSxmI0HRL2BJfrud1ev5q=2b800608b3c788349e3d477c20824dbe
             monad-logger-0.3.28.5-69Y7FXssjPV28LuWkhfKtw=f4af6727e1ddbede3ffcacbe128baf23
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW=cd76e68cc8b98f29153c4833d11aa72a
             http-api-data-0.3.8.1-DbbYF9lweepAWqzK9OsOgh=068007ba845e8769ec1fd0140d335eca
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.5.4-78-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.5.4
id: persistent-template-2.5.4-AsveY2BfkKd6Rtap8G3e6O
key: persistent-template-2.5.4-AsveY2BfkKd6Rtap8G3e6O
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
abi: a79f337455922df3ef9a06be6abcd81f
exposed: True
exposed-modules:
    Database.Persist.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-template-2.5.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/persistent-template-2.5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/persistent-template-2.5.4
hs-libraries: HSpersistent-template-2.5.4-AsveY2BfkKd6Rtap8G3e6O
depends:
    base-4.11.1.0 template-haskell-2.13.0.0
    persistent-2.8.2-4gAbVUv9dgvB3qZZOqbAZw
    monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk bytestring-0.10.8.2
    text-1.2.3.0 transformers-0.5.5.0 containers-0.5.11.0
    aeson-1.3.1.1-6HkD4IOtKBsKBv5cbRyt47
    aeson-compat-0.3.8-IfbeM07ze3EJUXaCzsukFA
    monad-logger-0.3.29-DKE6RE1iAEZGY539VXV4TF
    unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
    http-api-data-0.3.8.1-7V5OnCQ59z8FYWTajildiL ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             persistent-2.8.2-4gAbVUv9dgvB3qZZOqbAZw=a180821ca6edc9cc48c751999b7ea49c
             monad-control-1.0.2.3-I3eeoimEMDTINIqXKgCbLk=7b91fe2931b6520a589ebb0da769a2de
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             aeson-1.3.1.1-6HkD4IOtKBsKBv5cbRyt47=f2b384712f64489a53b966926a554aaf
             aeson-compat-0.3.8-IfbeM07ze3EJUXaCzsukFA=5e0ce04fa382044cf5012bb73a77e352
             monad-logger-0.3.29-DKE6RE1iAEZGY539VXV4TF=3af5c3e78a6e1871025b8786a4dec6de
             unordered-containers-0.2.9.0-IEc9LFcTDjK6w3ap4NqwQu=5b052eced98346d45f3db03378f2841d
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW=cd76e68cc8b98f29153c4833d11aa72a
             http-api-data-0.3.8.1-7V5OnCQ59z8FYWTajildiL=862d5c5cef6402769ce17d28a6488005
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
